# Testing the Tarballer Utility

This directory contains test scripts for validating the functionality of the Tarballer utility.

## Test Environment

All tests run in a Docker container with temporary files stored in the container's `/tmp` directory. This directory is:

1. Automatically created and managed by the container
2. Cleaned up after tests complete (unless you specify otherwise)
3. Internal to the container, so no files are written to the host filesystem

## Running Tests

To run the tests, use Docker Compose from the project root:

```bash
# Build and run all tests
docker compose up --build

# Run only the basic test
docker compose run tarballer /bin/test.sh basic

# Run only the tar comparison test
docker compose run tarballer /bin/test.sh tar

# Keep temporary files after tests (for debugging)
docker compose run tarballer /bin/test.sh all 1
```

## Test Types

The test script (`test.sh`) supports several test types:

1. `basic` - Tests basic tarball creation and extraction with various file types and symlinks
2. `tar` - Compares our utility against standard tar functionality
3. `all` - Runs all tests (default)
4. `clean` - Just cleans up temporary files

## Test Directory Structure

The tests create the following structure in the container's `/tmp` directory:

- `/tmp/complex/` - Directory with complex nested structure for basic test
- `/tmp/complex-extracted/` - Where the complex test tarball is extracted
- `/tmp/standard-test/` - Directory with sample app structure for tar comparison
- `/tmp/standard-extracted/` - Where our utility's tarball is extracted
- `/tmp/reference-extracted/` - Where standard tar's tarball is extracted

## Manual Testing

If you need to manually test the tarballer utility, you can:

1. Build the binaries: `docker compose up --build`
2. Use the binaries in `./bin/` directory:
   ```bash
   # Create a tarball
   ./bin/tarballer-darwin -source /path/to/source -output output.tar.gz -prefix myapp
   
   # Extract and verify a tarball
   ./bin/tarballer-darwin -extract -output output.tar.gz -extractdir /path/to/extract
   ```

## Modifying Tests

When modifying tests, keep in mind that the test script uses the container's `/tmp` directory for all temporary files. This keeps the test process self-contained within the container. 